==> haskell-dependent-sum-template-0.2.0.2-9.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum-template
version:              0.2.0.2
visibility:           public
id:                   dependent-sum-template-0.2.0.2-C3k8SZAQ2617sSx4TXmCey
key:                  dependent-sum-template-0.2.0.2-C3k8SZAQ2617sSx4TXmCey
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum-template
synopsis:
    Template Haskell code to generate instances of classes in some package

description:
    Template Haskell code to generate instances of classes in some package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  36494e615053dbaa0b2625060d1ff1e6
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.GADT.TH.Internal Data.GADT.Compare.Monad
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.2.0.2-C3k8SZAQ2617sSx4TXmCey
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.2.0.2-10-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum-template
version:              0.2.0.2
visibility:           public
id:                   dependent-sum-template-0.2.0.2-Gh1YV8UMc8jD2hwDtSyzwA
key:                  dependent-sum-template-0.2.0.2-Gh1YV8UMc8jD2hwDtSyzwA
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum-template
synopsis:
    Template Haskell code to generate instances of classes in some package

description:
    Template Haskell code to generate instances of classes in some package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  ea5d8cdc62908bad29ff5e9e3b2924b2
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.GADT.TH.Internal Data.GADT.Compare.Monad
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/dependent-sum-template-0.2.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.2.0.2-Gh1YV8UMc8jD2hwDtSyzwA
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
